"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardTableV2 = void 0;
const extended_table_v2_1 = require("./extended-table-v2");
const aws_dynamodb_1 = require("aws-cdk-lib/aws-dynamodb");
const aws_cdk_lib_1 = require("aws-cdk-lib");
/**
 * Standard DynamoDB Table V2 with a defined primary key and sort key.
 */
class StandardTableV2 extends extended_table_v2_1.ExtendedTableV2 {
    constructor(scope, id, props) {
        var _a, _b, _c, _d;
        const { globalSecondaryIndexes, globalSecondaryIndexReadCapacity, globalSecondaryIndexWriteCapacity, ...rest } = props || {};
        super(scope, id, {
            timeToLiveAttribute: props === null || props === void 0 ? void 0 : props.timeToLiveAttribute,
            partitionKey: (_a = props === null || props === void 0 ? void 0 : props.partitionKey) !== null && _a !== void 0 ? _a : {
                name: 'Pk',
                type: aws_dynamodb_1.AttributeType.STRING,
            },
            sortKey: (props === null || props === void 0 ? void 0 : props.sortKey) === null
                ? undefined
                : (_b = props === null || props === void 0 ? void 0 : props.sortKey) !== null && _b !== void 0 ? _b : {
                    name: 'Sk',
                    type: aws_dynamodb_1.AttributeType.STRING,
                },
            deletionProtection: (_c = props === null || props === void 0 ? void 0 : props.deletionProtection) !== null && _c !== void 0 ? _c : true,
            removalPolicy: (_d = props === null || props === void 0 ? void 0 : props.removalPolicy) !== null && _d !== void 0 ? _d : aws_cdk_lib_1.RemovalPolicy.RETAIN,
            ...rest,
        });
        this.secondaryIndexCount = 0;
        if (globalSecondaryIndexes && globalSecondaryIndexes > 0) {
            for (let i = 0; i < globalSecondaryIndexes; i++) {
                this.addGlobalSecondaryIndex({
                    readCapacity: globalSecondaryIndexReadCapacity,
                    writeCapacity: globalSecondaryIndexWriteCapacity,
                });
            }
        }
    }
    /**
     * Add a global secondary index of table.
     *
     * @param props the property of global secondary index
     */
    addGlobalSecondaryIndex(props) {
        var _a, _b, _c;
        this.secondaryIndexCount++;
        const indexName = (_a = props.indexName) !== null && _a !== void 0 ? _a : `Gs${this.secondaryIndexCount}`;
        super.addGlobalSecondaryIndex({
            indexName,
            partitionKey: (_b = props.partitionKey) !== null && _b !== void 0 ? _b : {
                name: `Gs${this.secondaryIndexCount}Pk`,
                type: aws_dynamodb_1.AttributeType.STRING,
            },
            sortKey: props.sortKey === null
                ? undefined
                : (_c = props.sortKey) !== null && _c !== void 0 ? _c : {
                    name: `Gs${this.secondaryIndexCount}Sk`,
                    type: aws_dynamodb_1.AttributeType.STRING,
                },
            ...props,
        });
        if (this.tableAlarms) {
            this.tableAlarms.addGlobalSecondaryIndexMonitoring(indexName);
        }
    }
}
exports.StandardTableV2 = StandardTableV2;
//# sourceMappingURL=standard-table-v2.js.map