"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StandardQueue = void 0;
const aws_cdk_lib_1 = require("aws-cdk-lib");
const aws_sqs_1 = require("aws-cdk-lib/aws-sqs");
const extended_queue_1 = require("./extended-queue");
const aws_cdk_1 = require("../../aws-cdk");
const truemark_1 = require("../../truemark");
const standard_dead_letter_queue_1 = require("./standard-dead-letter-queue");
class StandardQueue extends aws_cdk_1.ExtendedConstruct {
    constructor(scope, id, props) {
        var _a, _b, _c, _d, _e, _f, _g;
        super(scope, id, {
            standardTags: aws_cdk_1.StandardTags.merge(props === null || props === void 0 ? void 0 : props.standardTags, truemark_1.LibStandardTags),
        });
        const maxReceiveCount = (_a = props === null || props === void 0 ? void 0 : props.maxReceiveCount) !== null && _a !== void 0 ? _a : StandardQueue.DEFAULT_MAX_RECEIVE_COUNT;
        const encryption = (props === null || props === void 0 ? void 0 : props.encryptionMasterKey) === undefined
            ? aws_sqs_1.QueueEncryption.KMS_MANAGED
            : aws_sqs_1.QueueEncryption.KMS;
        const encryptionMasterKey = props === null || props === void 0 ? void 0 : props.encryptionMasterKey;
        const dataKeyReuse = (_b = props === null || props === void 0 ? void 0 : props.dataKeyReuse) !== null && _b !== void 0 ? _b : aws_cdk_lib_1.Duration.minutes(15);
        const deadLetterQueue = maxReceiveCount <= 0
            ? undefined
            : {
                queue: new standard_dead_letter_queue_1.StandardDeadLetterQueue(this, 'Dlq', {
                    queueName: props === null || props === void 0 ? void 0 : props.deadLetterQueueName,
                    encryption,
                    encryptionMasterKey,
                    dataKeyReuse,
                    receiveMessageWaitTime: props === null || props === void 0 ? void 0 : props.receiveMessageWaitTime,
                    retentionPeriod: props === null || props === void 0 ? void 0 : props.retentionPeriod,
                }),
                // queue: new Queue(this, 'Dlq', {
                //   queueName: props?.deadLetterQueueName,
                //   encryption,
                //   encryptionMasterKey,
                //   dataKeyReuse,
                //   fifo: props?.fifo,
                //   receiveMessageWaitTime:
                //     props?.receiveMessageWaitTime ?? Duration.seconds(20),
                //   retentionPeriod: StandardQueue.DEFAULT_RETENTION_PERIOD,
                // }),
                maxReceiveCount,
            };
        this.queue = new extended_queue_1.ExtendedQueue(this, 'Default', {
            ...props,
            deadLetterQueue,
            encryption,
            encryptionMasterKey,
            dataKeyReuse,
            fifo: props === null || props === void 0 ? void 0 : props.fifo,
            receiveMessageWaitTime: (_c = props === null || props === void 0 ? void 0 : props.receiveMessageWaitTime) !== null && _c !== void 0 ? _c : aws_cdk_lib_1.Duration.seconds(20),
            alarmFriendlyName: (_d = props === null || props === void 0 ? void 0 : props.alarmFriendlyName) !== null && _d !== void 0 ? _d : id,
            retentionPeriod: (_e = props === null || props === void 0 ? void 0 : props.retentionPeriod) !== null && _e !== void 0 ? _e : StandardQueue.DEFAULT_RETENTION_PERIOD,
            visibilityTimeout: (_f = props === null || props === void 0 ? void 0 : props.visibilityTimeout) !== null && _f !== void 0 ? _f : aws_cdk_lib_1.Duration.seconds(30),
            alarmNamePrefix: (_g = props === null || props === void 0 ? void 0 : props.alarmNamePrefix) !== null && _g !== void 0 ? _g : aws_cdk_lib_1.Stack.of(this).stackName + '-' + id,
        });
        this.queueArn = this.queue.queueArn;
        this.queueUrl = this.queue.queueUrl;
        this.queueName = this.queue.queueName;
        this.encryptionMasterKey = this.queue.encryptionMasterKey;
        this.fifo = this.queue.fifo;
        this.stack = this.queue.stack;
        this.env = this.queue.env;
    }
    // From IQueue
    addToResourcePolicy(statement) {
        return this.queue.addToResourcePolicy(statement);
    }
    grantConsumeMessages(grantee) {
        return this.queue.grantConsumeMessages(grantee);
    }
    grantSendMessages(grantee) {
        return this.queue.grantSendMessages(grantee);
    }
    grantPurge(grantee) {
        return this.queue.grantPurge(grantee);
    }
    grant(grantee, ...queueActions) {
        return this.queue.grant(grantee, ...queueActions);
    }
    metric(metricName, props) {
        return this.queue.metric(metricName, props);
    }
    metricApproximateAgeOfOldestMessage(props) {
        return this.queue.metricApproximateAgeOfOldestMessage(props);
    }
    metricApproximateNumberOfMessagesDelayed(props) {
        return this.queue.metricApproximateNumberOfMessagesDelayed(props);
    }
    metricApproximateNumberOfMessagesNotVisible(props) {
        return this.queue.metricApproximateNumberOfMessagesNotVisible(props);
    }
    metricApproximateNumberOfMessagesVisible(props) {
        return this.queue.metricApproximateNumberOfMessagesVisible(props);
    }
    metricNumberOfEmptyReceives(props) {
        return this.queue.metricNumberOfEmptyReceives(props);
    }
    metricNumberOfMessagesDeleted(props) {
        return this.queue.metricNumberOfMessagesDeleted(props);
    }
    metricNumberOfMessagesReceived(props) {
        return this.queue.metricNumberOfMessagesReceived(props);
    }
    metricNumberOfMessagesSent(props) {
        return this.queue.metricNumberOfMessagesSent(props);
    }
    metricSentMessageSize(props) {
        return this.queue.metricSentMessageSize(props);
    }
    applyRemovalPolicy(policy) {
        return this.queue.applyRemovalPolicy(policy);
    }
}
exports.StandardQueue = StandardQueue;
StandardQueue.DEFAULT_MAX_RECEIVE_COUNT = 3;
StandardQueue.DEFAULT_RETENTION_PERIOD = aws_cdk_lib_1.Duration.seconds(1209600);
//# sourceMappingURL=standard-queue.js.map